@@ -1,10 +1,14 @@
-from __future__ import print_function
+#!/usr/bin/env python
 import os, sys, unittest, tempfile, shlex
 
 if sys.hexversion > 0x03000000:
 	def execfile(file, globals=globals(), locals=locals()):
-		with open(file, "r") as fh:
-			exec(fh.read()+"\n", globals, locals)
+		fh = open(file, "r")
+		if not fh: raise Exception("Unable to open %s." % file)
+		exec(fh.read()+"\n", globals, locals)
+		# The code below is not parsed by python2.5
+		#with open(file, "r") as fh:
+		#	exec(fh.read()+"\n", globals, locals)
 
 def execfile2(filename, _globals=dict(), _locals=dict(), cmd=None, quiet=False):
 	"""
@@ -35,7 +39,8 @@ def execfile2(filename, _globals=dict(), _locals=dict(), cmd=None, quiet=False):
 	try:
 		execfile(filename, _globals, _locals)
 		
-	except SystemExit as e:
+	except SystemExit:
+		type, e, tb = sys.exc_info()
 		if isinstance(e.code , int):
 			exit_code = e.code # this could be 0 if you do sys.exit(0)
 		else:
